# coding: utf-8
"""
SampleDB API package
"""

from . import server

__all__ = [
    'server'
]
